# -*- coding: utf-8 -*-

from io import BytesIO

import requests
from line_image_extractor.image_utils import resize
from PIL import Image

from kaldi_data_generator.utils import TranscriptionData, logger


def download_image(url):
    """
    Download an image and open it with Pillow
    """
    assert url.startswith("http"), "Image URL must be HTTP(S)"
    # Download the image
    # Cannot use stream=True as urllib's responses do not support the seek(int) method,
    # which is explicitly required by Image.open on file-like objects
    resp = requests.get(url)
    resp.raise_for_status()

    # Preprocess the image and prepare it for classification
    image = Image.open(BytesIO(resp.content))
    logger.debug(
        "Downloaded image {} - size={}x{}".format(url, image.size[0], image.size[1])
    )

    return image


def resize_transcription_data(
    trans: TranscriptionData,
    max_width: int,
    max_height: int,
    scale_x: float,
    scale_y_top: float,
    scale_y_bottom: float,
) -> TranscriptionData:
    orig_polygon = trans.polygon
    resized_polygon = resize(
        orig_polygon, max_width, max_height, scale_x, scale_y_top, scale_y_bottom
    )

    return TranscriptionData.copy_replace_polygon(trans, resized_polygon)
