# -*- coding: utf-8 -*-
import json
import os
from pathlib import Path

import pytest
from arkindex.mock import MockApiClient
from line_image_extractor import extractor

TEST_WORKER_VERSION_ID = "1234-kaldi"

TEST_VOLUME_ID = "6ebebd79-2a28-464f-b60a-aa47a864a586"

FIXTURES = Path(__file__).resolve().parent / "data"


@pytest.fixture(autouse=True)
def setup_environment(responses):
    """Setup needed environment variables"""

    # Allow accessing remote API schemas
    # defaulting to the prod environment
    schema_url = os.environ.get(
        "ARKINDEX_API_SCHEMA_URL",
        "https://arkindex.teklia.com/api/v1/openapi/?format=openapi-json",
    )
    responses.add_passthru(schema_url)

    # Setup a fake worker version ID
    os.environ["WORKER_VERSION_ID"] = TEST_WORKER_VERSION_ID


@pytest.fixture
def fake_volume_id():
    return TEST_VOLUME_ID


@pytest.fixture
def fake_image():
    img_path = FIXTURES / "pinned_insects/d336445e-a3ea-4278-a973-a14daefab229.jpg"
    return extractor.read_img(img_path)


@pytest.fixture
def fake_run_filter_metadata():
    api_client = MockApiClient()
    # ignore caching for this test
    api_client.cached_paginate = api_client.paginate
    with open(FIXTURES / "Maurdor/ListElementChildren/fake_page.json") as f:
        pages_json = json.load(f)
        api_client.add_response(
            "ListElementChildren",
            response=pages_json,
            id="fake_page",
            with_classes=False,
            with_metadata=True,
            recursive=True,
        )
    return api_client


@pytest.fixture
def fake_run_volume_api_client(fake_volume_id):
    api_client = MockApiClient()
    # ignore caching for this test
    api_client.cached_paginate = api_client.paginate
    with open(
        FIXTURES / "pinned_insects/ListElementChildren" / f"{fake_volume_id}.json"
    ) as f:
        pages_json = json.load(f)
        api_client.add_response(
            "ListElementChildren",
            response=pages_json,
            id=fake_volume_id,
            recursive=True,
            type="page",
        )

    trans_dir = FIXTURES / "pinned_insects/ListTranscriptions"
    for trans_file in trans_dir.glob("*.json"):
        trans_json = json.loads(trans_file.read_text())

        api_client.add_response(
            "ListTranscriptions",
            response=trans_json,
            id=trans_file.stem,
            recursive=True,
        )

    return api_client


@pytest.fixture
def fake_expected_partitions():
    partitions_dir = FIXTURES / "pinned_insects/partitions"
    return {
        part_file.name: part_file.read_text().strip().split("\n")
        for part_file in partitions_dir.glob("*.lst")
    }
